==> lxqt-l10n-0.11.0-1-src.tar.xz: lxqt-l10n-0.11.0/lxqt-panel/plugin-clock/clock_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>FirstDayCombo</name>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="49"/>
        <source>&lt;locale based&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtClockConfiguration</name>
    <message>
        <source>LXQt Clock Settings</source>
        <translation type="vanished">Definições do relógio LXQt</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="14"/>
        <source>Clock Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="20"/>
        <source>Time</source>
        <translation>Horas</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="26"/>
        <source>&amp;Show seconds</source>
        <translation>Mo&amp;strar segundos</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="33"/>
        <source>12 &amp;hour style</source>
        <translation>Estilo 12 &amp;horas</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="40"/>
        <source>&amp;Use UTC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="59"/>
        <source>Date &amp;format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="76"/>
        <source>&amp;Do not show date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="86"/>
        <source>Show date &amp;before time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="93"/>
        <source>Show date &amp;after time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="100"/>
        <source>Show date below time on new &amp;line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="107"/>
        <source>First day of week in calendar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="124"/>
        <source>Orientation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="130"/>
        <source>Auto&amp;rotate when the panel is vertical</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Font</source>
        <translation type="vanished">Tipo &amp;de letra</translation>
    </message>
    <message>
        <source>Font</source>
        <translation type="vanished">Tipo de letra</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="50"/>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Show &amp;date</source>
        <translation type="vanished">Mostrar &amp;data</translation>
    </message>
    <message>
        <source>D&amp;ate format</source>
        <translation type="vanished">Form&amp;ato da data</translation>
    </message>
    <message>
        <source>Fon&amp;t</source>
        <translation type="vanished">&amp;Tipo de letra</translation>
    </message>
    <message>
        <source>Show date in &amp;new line</source>
        <translation type="vanished">Mostrar data em linha disti&amp;nta</translation>
    </message>
    <message>
        <source>&amp;Use theme fonts</source>
        <translation type="vanished">&amp;Utilizar tipo de letra do tema</translation>
    </message>
    <message>
        <source>Time font</source>
        <translation type="vanished">Tipo de letra das horas</translation>
    </message>
    <message>
        <source>Date font</source>
        <translation type="vanished">Tipo de letra da data</translation>
    </message>
    <message>
        <source>Ultra light</source>
        <translation type="vanished">Mais clara</translation>
    </message>
    <message>
        <source>Light</source>
        <translation type="vanished">Clara</translation>
    </message>
    <message>
        <source>Ultra black</source>
        <translation type="vanished">Normal carregado</translation>
    </message>
    <message>
        <source>Black</source>
        <translation type="vanished">Normal</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation type="vanished">Negrito</translation>
    </message>
    <message>
        <source>Demi bold</source>
        <translation type="vanished">Negrito suave</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation type="vanished">Itálico</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="268"/>
        <source>Input custom date format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="268"/>
        <source>Interpreted sequences of date format are:

d	the day as number without a leading zero (1 to 31)
dd	the day as number with a leading zero (01 to 31)
ddd	the abbreviated localized day name (e.g. &apos;Mon&apos; to &apos;Sun&apos;).
dddd	the long localized day name (e.g. &apos;Monday&apos; to &apos;Sunday&apos;).
M	the month as number without a leading zero (1-12)
MM	the month as number with a leading zero (01-12)
MMM	the abbreviated localized month name (e.g. &apos;Jan&apos; to &apos;Dec&apos;).
MMMM	the long localized month name (e.g. &apos;January&apos; to &apos;December&apos;).
yy	the year as two digit number (00-99)
yyyy	the year as four digit number

All other input characters will be treated as text.
Any sequence of characters that are enclosed in single quotes (&apos;)
will also be treated as text and not be used as an expression.


Custom date format:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> lxqt-l10n-0.12.0-1-src.tar.xz: lxqt-l10n-0.12.0/lxqt-panel/plugin-clock/clock_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>FirstDayCombo</name>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="49"/>
        <source>&lt;locale based&gt;</source>
        <translation>&lt;baseado na configuração regional&gt;</translation>
    </message>
</context>
<context>
    <name>LXQtClock</name>
    <message>
        <location filename="../../../lxqtclock.cpp" line="57"/>
        <source>Date&amp;Time (clock) plugin is deprecated</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtclock.cpp" line="58"/>
        <source>The &lt;strong&gt;clock&lt;/strong&gt; plugin is deprecated and will be removed in future version of LXQt. Consider replacing it with &lt;strong&gt;worldclock&lt;/strong&gt;.&lt;br/&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtclock.cpp" line="60"/>
        <source>don&apos;t show this again</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtClockConfiguration</name>
    <message>
        <source>LXQt Clock Settings</source>
        <translation type="vanished">Definições do relógio LXQt</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="14"/>
        <source>Clock Settings</source>
        <translation>Definições do relógio</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="20"/>
        <source>Time</source>
        <translation>Horas</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="26"/>
        <source>&amp;Show seconds</source>
        <translation>Mo&amp;strar segundos</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="33"/>
        <source>12 &amp;hour style</source>
        <translation>Estilo 12 &amp;horas</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="40"/>
        <source>&amp;Use UTC</source>
        <translation>Usar &amp;UTC</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="59"/>
        <source>Date &amp;format</source>
        <translation>&amp;Formato de data</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="76"/>
        <source>&amp;Do not show date</source>
        <translation>Não mostrar &amp;data</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="86"/>
        <source>Show date &amp;before time</source>
        <translation>Mostrar data &amp;antes das horas</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="93"/>
        <source>Show date &amp;after time</source>
        <translation>Mostrar data depois d&amp;as horas</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="100"/>
        <source>Show date below time on new &amp;line</source>
        <translation>Mostrar data por &amp;baixo das horas</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="107"/>
        <source>First day of week in calendar</source>
        <translation>Primeiro dia da semana</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="124"/>
        <source>Orientation</source>
        <translation>Orientação</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="130"/>
        <source>Auto&amp;rotate when the panel is vertical</source>
        <translation>&amp;Rodar automaticamente se o painel for vertical</translation>
    </message>
    <message>
        <source>&amp;Font</source>
        <translation type="vanished">Tipo &amp;de letra</translation>
    </message>
    <message>
        <source>Font</source>
        <translation type="vanished">Tipo de letra</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="50"/>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Show &amp;date</source>
        <translation type="vanished">Mostrar &amp;data</translation>
    </message>
    <message>
        <source>D&amp;ate format</source>
        <translation type="vanished">Form&amp;ato da data</translation>
    </message>
    <message>
        <source>Fon&amp;t</source>
        <translation type="vanished">&amp;Tipo de letra</translation>
    </message>
    <message>
        <source>Show date in &amp;new line</source>
        <translation type="vanished">Mostrar data em linha disti&amp;nta</translation>
    </message>
    <message>
        <source>&amp;Use theme fonts</source>
        <translation type="vanished">&amp;Utilizar tipo de letra do tema</translation>
    </message>
    <message>
        <source>Time font</source>
        <translation type="vanished">Tipo de letra das horas</translation>
    </message>
    <message>
        <source>Date font</source>
        <translation type="vanished">Tipo de letra da data</translation>
    </message>
    <message>
        <source>Ultra light</source>
        <translation type="vanished">Mais clara</translation>
    </message>
    <message>
        <source>Light</source>
        <translation type="vanished">Clara</translation>
    </message>
    <message>
        <source>Ultra black</source>
        <translation type="vanished">Normal carregado</translation>
    </message>
    <message>
        <source>Black</source>
        <translation type="vanished">Normal</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation type="vanished">Negrito</translation>
    </message>
    <message>
        <source>Demi bold</source>
        <translation type="vanished">Negrito suave</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation type="vanished">Itálico</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="268"/>
        <source>Input custom date format</source>
        <translation>Formato personalizado de data</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="268"/>
        <source>Interpreted sequences of date format are:

d	the day as number without a leading zero (1 to 31)
dd	the day as number with a leading zero (01 to 31)
ddd	the abbreviated localized day name (e.g. &apos;Mon&apos; to &apos;Sun&apos;).
dddd	the long localized day name (e.g. &apos;Monday&apos; to &apos;Sunday&apos;).
M	the month as number without a leading zero (1-12)
MM	the month as number with a leading zero (01-12)
MMM	the abbreviated localized month name (e.g. &apos;Jan&apos; to &apos;Dec&apos;).
MMMM	the long localized month name (e.g. &apos;January&apos; to &apos;December&apos;).
yy	the year as two digit number (00-99)
yyyy	the year as four digit number

All other input characters will be treated as text.
Any sequence of characters that are enclosed in single quotes (&apos;)
will also be treated as text and not be used as an expression.


Custom date format:</source>
        <translation>As sequências possíveis para o formato de data são as seguintes:

d	o dia da semana sem o zero inicial (1 a 31)
dd	o dia da semana com o zero inicial (01 a 31)
ddd	o nome abreviado do dia da semana (seg a dom)
dddd	o nome completo do dia da semana (segunda-feira a domingo)
M	o mês, como número e sem o zero inicial (1 a12)
MM	o mês, como número e com o zero inicial (01 a 12)
MMM	o nome abreviado do mês (jan a dez)
MMMM	o nome completo do mês (janeiro a dezembro)
yy	o ano no formato de dois dígitos (00 a 99)
yyyy	o ano no formato de quatro dígitos

Todas as outras sequências de caracteres serão tratadas como texto.
Quaisquer sequências de caracteres entre apóstrofos (&apos;) também
serão tratadas como texto e não serão utilizadas como expressão.


Formato personalizado:</translation>
    </message>
</context>
</TS>
